==> haskell-genvalidity-1.1.1.0-76.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-1cygiBXmr98EcwwcYom5CO
key:                  genvalidity-1.1.1.0-1cygiBXmr98EcwwcYom5CO
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  8b65c004a109458f7cc4f64f13676388
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-1cygiBXmr98EcwwcYom5CO
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    validity-0.12.1.0-Lsdq3S1YVx6GOnXZaTodRl

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-1.1.1.0-77-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-4ORseef1Qsj9tj2fPe8Pqa
key:                  genvalidity-1.1.1.0-4ORseef1Qsj9tj2fPe8Pqa
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  a7ae68f379faad14c6d28a2b03b12338
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-4ORseef1Qsj9tj2fPe8Pqa
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    validity-0.12.1.0-1ywEh9iJU1m6FQwCfRBtqj

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
